#pragma once
#include "api/base_op.h"

namespace fg {
namespace functor {
  class EditDistanceFunctor;
}

using std::string;
using std::vector;


/**
 * @brief 编辑距离：输入两个字符串，输出是它们的文本编辑距离
 */
class EditDistance : public IFeatureOP {
 public:
  int Initialize(const string& feature_config) override;

  /// @return 状态码，如果为0表示执行成功
  int ProcessWithStrOutputs(const vector<Field>& inputs,
                            vector<string>& outputs) override;

  /// @return 状态码，如果为0表示执行成功
  int ProcessWithInt32Outputs(const vector<Field>& inputs,
                              vector<int32>& outputs) override;

  /// @return 状态码，如果为0表示执行成功
  int ProcessWithInt64Outputs(const vector<Field>& inputs,
                              vector<int64>& outputs) override;

  /// @return 状态码，如果为0表示执行成功
  int ProcessWithFloatOutputs(const vector<Field>& inputs,
                              vector<float>& outputs) override;

  /// @return 状态码，如果为0表示执行成功
  int ProcessWithDoubleOutputs(const vector<Field>& inputs,
                               vector<double>& outputs) override;

 private:
  string feature_name_;
  std::unique_ptr<functor::EditDistanceFunctor> functor_p_;
};

}  // end of namespace fg

REGISTER_PLUGIN("EditDistance", EditDistance);